@@ -9,14 +9,12 @@
     :license: BSD, see LICENSE for details.
 """
 
+import pytest
 from six import iteritems, StringIO
 
-from sphinx.ext.autosummary import mangle_signature
-
+from sphinx.ext.autosummary import mangle_signature, import_by_name, extract_summary
 from sphinx.testing.util import etree_parse
 
-import pytest
-
 html_warnfile = StringIO()
 
 
@@ -57,11 +55,38 @@ def test_mangle_signature():
         assert res == outp, (u"'%s' -> '%s' != '%s'" % (inp, res, outp))
 
 
+def test_extract_summary():
+    from sphinx.util.docutils import new_document
+    from mock import Mock
+    settings = Mock(language_code='',
+                    id_prefix='',
+                    auto_id_prefix='',
+                    pep_reference=False,
+                    rfc_reference=False)
+    document = new_document('', settings)
+
+    # normal case
+    doc = ['',
+           'This is a first sentence. And second one.',
+           '',
+           'Second block is here']
+    assert extract_summary(doc, document) == 'This is a first sentence.'
+
+    # inliner case
+    doc = ['This sentence contains *emphasis text having dots.*,',
+           'it does not break sentence.']
+    assert extract_summary(doc, document) == ' '.join(doc)
+
+
 @pytest.mark.sphinx('dummy', **default_kw)
-def test_get_items_summary(app, status, warning):
+def test_get_items_summary(make_app, app_params):
+    import sphinx.ext.autosummary
+    import sphinx.ext.autosummary.generate
+    args, kwargs = app_params
+    app = make_app(*args, **kwargs)
+    sphinx.ext.autosummary.generate.setup_documenters(app)
     # monkey-patch Autosummary.get_items so we can easily get access to it's
     # results..
-    import sphinx.ext.autosummary
     orig_get_items = sphinx.ext.autosummary.Autosummary.get_items
 
     autosummary_items = {}
@@ -74,6 +99,10 @@ def test_get_items_summary(app, status, warning):
 
     def handler(app, what, name, obj, options, lines):
         assert isinstance(lines, list)
+
+        # ensure no docstring is processed twice:
+        assert 'THIS HAS BEEN HANDLED' not in lines
+        lines.append('THIS HAS BEEN HANDLED')
     app.connect('autodoc-process-docstring', handler)
 
     sphinx.ext.autosummary.Autosummary.get_items = new_get_items
@@ -82,12 +111,12 @@ def test_get_items_summary(app, status, warning):
     finally:
         sphinx.ext.autosummary.Autosummary.get_items = orig_get_items
 
-    html_warnings = warning.getvalue()
+    html_warnings = app._warning.getvalue()
     assert html_warnings == ''
 
     expected_values = {
         'withSentence': 'I have a sentence which spans multiple lines.',
-        'noSentence': "this doesn't start with a",
+        'noSentence': "this doesn't start with a capital.",
         'emptyLine': "This is the real summary",
         'module_attr': 'This is a module attribute',
         'C.class_attr': 'This is a class attribute',
@@ -146,3 +175,31 @@ def test_autosummary_generate(app, status, warning):
             '      ~Foo.__init__\n'
             '      ~Foo.bar\n'
             '   \n' in Foo)
+    assert ('   .. autosummary::\n'
+            '   \n'
+            '      ~Foo.baz\n'
+            '   \n' in Foo)
+
+
+def test_import_by_name():
+    import sphinx
+    import sphinx.ext.autosummary
+
+    prefixed_name, obj, parent, modname = import_by_name('sphinx')
+    assert prefixed_name == 'sphinx'
+    assert obj is sphinx
+    assert parent is None
+    assert modname == 'sphinx'
+
+    prefixed_name, obj, parent, modname = import_by_name('sphinx.ext.autosummary.__name__')
+    assert prefixed_name == 'sphinx.ext.autosummary.__name__'
+    assert obj is sphinx.ext.autosummary.__name__
+    assert parent is sphinx.ext.autosummary
+    assert modname == 'sphinx.ext.autosummary'
+
+    prefixed_name, obj, parent, modname = \
+        import_by_name('sphinx.ext.autosummary.Autosummary.get_items')
+    assert prefixed_name == 'sphinx.ext.autosummary.Autosummary.get_items'
+    assert obj == sphinx.ext.autosummary.Autosummary.get_items
+    assert parent is sphinx.ext.autosummary.Autosummary
+    assert modname == 'sphinx.ext.autosummary'
